@@ -6,7 +6,7 @@ httpget_package_data <- function(pkgpath, requri){
   
   #Package has to be loaded from reqlib, but dependencies might be loaded from global libs.
   inlib(reqlib,{
-    library(reqpackage, lib.loc=reqlib, character.only=TRUE);
+    loadPackageFrom(reqpackage, reqlib);
     
     #reqhead is function/object name
     reqobject <- head(requri, 1);
