@@ -15,10 +15,10 @@ rapachehandler <- function(){
     MYRAW <- NULL;
     NEWPOST <- getrapache("POST");
     NEWFILES <- getrapache("FILES");
-    NEWPOST[names(NEWFILES)] <- NULL;    
+    NEWPOST[names(NEWFILES)] <- NULL;
   }
   
-	#collect request data from rapache
+  #collect request data from rapache
   REQDATA <- list(
     METHOD = getrapache("SERVER")$method,
     MOUNT = getrapache("SERVER")$cmd_path,
@@ -29,13 +29,13 @@ rapachehandler <- function(){
     RAW = MYRAW
   );
     
-	#select method to parse request in a trycatch 
+  #select method to parse request in a trycatch 
   tmpnull <- tempfile();
-	sink(tmpnull);
-	response <- serve(REQDATA);
-	sink();
+  sink(tmpnull);
+  response <- serve(REQDATA);
+  sink();
   unlink(tmpnull);
-	
+  
   #set server header  
   response$headers["X-ocpu-server"] <- "rApache";      
 
@@ -45,12 +45,16 @@ rapachehandler <- function(){
   #set headers
   headerlist <- response$headers;
   for(i in seq_along(headerlist)){
-    getrapache("setHeader")(names(headerlist[i]), headerlist[[i]]);    
+    if(identical(names(headerlist[i]), "Content-Type")){
+      getrapache("setContentType")(headerlist[[i]]);
+    } else {
+      getrapache("setHeader")(names(headerlist[i]), headerlist[[i]]);          
+    }
   }
-	  
+    
   #send buffered body
   getrapache("sendBin")(readBin(response$body,'raw',n=file.info(response$body)$size));
 
   #return
-	return(getrapache("OK"));
+  return(getrapache("OK"));
 }
